# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/110_npty.ipynb.

# %% auto 0
__all__ = ['NPArray', 'ndarray', 'NPMatrix', 'ndmatrix', 'DataSource']

# %% ../nbs/110_npty.ipynb 6
#| export


# %% ../nbs/110_npty.ipynb 8
from typing import TypeAlias, ForwardRef

# %% ../nbs/110_npty.ipynb 11
try:
    import numpy as np
    arr = np.ndarray
    mtx = np.matrix
    dsr = np.DataSource
    
except ImportError:
    # Define a placeholder type if numpy is not installed
    arr = ForwardRef('numpy.ndarray', module='numpy', is_class=True)
    mtx = ForwardRef('numpy.matrix', module='numpy', is_class=True)
    dsr = ForwardRef('numpy.DataSource', module='numpy', is_class=True)

# %% ../nbs/110_npty.ipynb 13
#| export


# %% ../nbs/110_npty.ipynb 15
#| export


# %% ../nbs/110_npty.ipynb 18
NPArray: TypeAlias = arr
ndarray: TypeAlias = arr

NPMatrix: TypeAlias = mtx
ndmatrix: TypeAlias = mtx

DataSource: TypeAlias = dsr
